@@ -2,7 +2,7 @@
 
 set -e
 # Start the notification daemon
-gtk-launch notification-daemon.desktop
+/usr/lib/notification-daemon/notification-daemon &
 sleep 1
 
 # Test with the requested versions of Python
